package org.serviio.ui.restlet;

import java.util.List;

import org.restlet.Application;
import org.restlet.Component;
import org.restlet.data.Protocol;
import org.restlet.engine.Engine;
import org.restlet.engine.converter.ConverterHelper;
import org.restlet.ext.gson.GsonConverter;
import org.serviio.ui.resources.RestletApplication;
import org.serviio.util.ObjectValidator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class RestletServer {
    private static final Logger log = LoggerFactory
            .getLogger(RestletServer.class);

    private static Component component = new Component();

    public static void runServer() {
        String remoteHost = System.getProperty("serviio.remoteHost");
        if (ObjectValidator.isEmpty(remoteHost)) {
            remoteHost = "localhost";
        }
        log.info(String.format("Starting Restlet server exposed on %s:%s",
                new Object[] { remoteHost, Integer.valueOf(23423) }));

        component.getServers().add(Protocol.HTTP, remoteHost, 23423);
        Application app = new RestletApplication();
        app.setStatusService(new ServiioStatusService());
        component.getDefaultHost().attach("/rest", app);

        // OFU
        List<ConverterHelper> registeredConverters = Engine.getInstance()
                .getRegisteredConverters();
        registeredConverters.add(0, new GsonConverter());
        registeredConverters.add(1, new ServiioXstreamConverter());
        // OFU
        try {
            component.start();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public static void stopServer() {
        try {
            component.stop();
        } catch (Exception e) {
            log.warn("Error during shutting down Restlet server", e);
        }
    }
}